@@ -31,6 +31,25 @@ def log_spot():
     timberlog.spot('example_spot_event')
 
 
+def log_classic_success():
+    try:
+        timberlog.start('log_classic_success')
+        timberlog.info(context={'msg': 'this is a classic successful log'})
+        timberlog.success()
+    except:
+        timberlog.end_with_error()
+
+
+def log_classic_error():
+    try:
+        timberlog.start('log_classic_error')
+        timberlog.info(context={'msg': 'this is a classic unsuccessful log'})
+        raise Exception()
+        timberlog.success()
+    except:
+        timberlog.end_with_error()
+
+
 if __name__ == '__main__':
     timberlog.init(os.getenv('timbermill_server_url'), 'example_env', static_event_params={'a': 1})
 
@@ -47,3 +66,6 @@ if __name__ == '__main__':
         pass
 
     log_spot()
+
+    log_classic_success()
+    log_classic_error()
